@@ -10,7 +10,7 @@ using Gtk;
 
 public partial class MainWindow: Gtk.Window
 {	
-
+	public string startBristol = "startBristol";
 	public string adriver, ogain, onogain, igain, oningain, rate, onrate;
 	public string mdriver, channel, onchannel;
 	public string voices, onvoices, tcp, host, ontcp, onhost, onpreload, preload, period, onperiod;
@@ -650,242 +650,242 @@ public partial class MainWindow: Gtk.Window
 	protected virtual void OnBmoogminiPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -mini");
+		System.Diagnostics.Process.Start (startBristol, param+" -mini");
 	}
 
 	protected virtual void OnBmoogvoyagerPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -explorer");
+		System.Diagnostics.Process.Start (startBristol, param+" -explorer");
 		
 	}
 
 	protected virtual void OnBvoybluePressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -voyager");
+		System.Diagnostics.Process.Start (startBristol, param+" -voyager");
 	}
 
 	protected virtual void OnBmoogmemoPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -memory");
+		System.Diagnostics.Process.Start (startBristol, param+" -memory");
 	}
 
 	protected virtual void OnBmoogrealPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -mg1");
+		System.Diagnostics.Process.Start (startBristol, param+" -mg1");
 	}
 
 	protected virtual void OnBsonicPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -sonic6");
+		System.Diagnostics.Process.Start (startBristol, param+" -sonic6");
 	}
 
 	protected virtual void OnBpro5Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -prophet");
+		System.Diagnostics.Process.Start (startBristol, param+" -prophet");
 	}
 
 	protected virtual void OnBpro10Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -pro10");
+		System.Diagnostics.Process.Start (startBristol, param+" -pro10");
 	}
 
 	protected virtual void OnBpro52Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -pro52");
+		System.Diagnostics.Process.Start (startBristol, param+" -pro52");
 	}
 
 	protected virtual void OnBpro1Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -pro1");
+		System.Diagnostics.Process.Start (startBristol, param+" -pro1");
 	}
 
 	protected virtual void OnBobxPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -obx");
+		System.Diagnostics.Process.Start (startBristol, param+" -obx");
 	}
 
 	protected virtual void OnBobxaPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -obxa");
+		System.Diagnostics.Process.Start (startBristol, param+" -obxa");
 	}
 
 	protected virtual void OnBaxxePressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -axxe");
+		System.Diagnostics.Process.Start (startBristol, param+" -axxe");
 	}
 
 	protected virtual void OnBodyPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -odyssey");
+		System.Diagnostics.Process.Start (startBristol, param+" -odyssey");
 	}
 
 	protected virtual void OnB2600Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -arp2600");
+		System.Diagnostics.Process.Start (startBristol, param+" -arp2600");
 	}
 
 	protected virtual void OnBsolinaPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -solina");
+		System.Diagnostics.Process.Start (startBristol, param+" -solina");
 	}
 
 	protected virtual void OnBjuno6Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -juno");
+		System.Diagnostics.Process.Start (startBristol, param+" -juno");
 	}
 
 	protected virtual void OnBjupiter8Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -jupiter");
+		System.Diagnostics.Process.Start (startBristol, param+" -jupiter");
 	}
 
 	protected virtual void OnBmonopolyPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -monopoly");
+		System.Diagnostics.Process.Start (startBristol, param+" -monopoly");
 	}
 
 	protected virtual void OnBms20Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -ms20");
+		System.Diagnostics.Process.Start (startBristol, param+" -ms20");
 	}
 
 	protected virtual void OnBpoly800Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -poly800");
+		System.Diagnostics.Process.Start (startBristol, param+" -poly800");
 	}
 
 	protected virtual void OnBpolysixPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -polysix");
+		System.Diagnostics.Process.Start (startBristol, param+" -polysix");
 	}
 
 	protected virtual void OnBvoxconPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -vox");
+		System.Diagnostics.Process.Start (startBristol, param+" -vox");
 	}
 
 	protected virtual void OnBcon300Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -voxM2");
+		System.Diagnostics.Process.Start (startBristol, param+" -voxM2");
 	}
 
 	protected virtual void OnBb3Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -b3");
+		System.Diagnostics.Process.Start (startBristol, param+" -b3");
 	}
 
 	protected virtual void OnBmodulPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -hammond");
+		System.Diagnostics.Process.Start (startBristol, param+" -hammond");
 	}
 
 	protected virtual void OnBrhode73Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -rhodes");
+		System.Diagnostics.Process.Start (startBristol, param+" -rhodes");
 	}
 
 	protected virtual void OnBrhodebassPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -rhodesbass");
+		System.Diagnostics.Process.Start (startBristol, param+" -rhodesbass");
 	}
 
 	protected virtual void OnBydxPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -dx");
+		System.Diagnostics.Process.Start (startBristol, param+" -dx");
 	}
 
 	protected virtual void OnBcs80Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -cs80");
+		System.Diagnostics.Process.Start (startBristol, param+" -cs80");
 	}
 
 	protected virtual void OnBbit1Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -bitone");
+		System.Diagnostics.Process.Start (startBristol, param+" -bitone");
 	}
 
 	protected virtual void OnBbit99Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -bit99");
+		System.Diagnostics.Process.Start (startBristol, param+" -bit99");
 	}
 
 	protected virtual void OnBbit100Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -bit100");
+		System.Diagnostics.Process.Start (startBristol, param+" -bit100");
 	}
 
 	protected virtual void OnBroadrunnerPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -roadrunner");
+		System.Diagnostics.Process.Start (startBristol, param+" -roadrunner");
 	}
 
 	protected virtual void OnBstratusPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -stratus");
+		System.Diagnostics.Process.Start (startBristol, param+" -stratus");
 	}
 
 	protected virtual void OnBtrilogyPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -trilogy");
+		System.Diagnostics.Process.Start (startBristol, param+" -trilogy");
 	}
 
 	protected virtual void OnBaksPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -aks");
+		System.Diagnostics.Process.Start (startBristol, param+" -aks");
 	}
 
 	protected virtual void OnBbme700Pressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -bme700");
+		System.Diagnostics.Process.Start (startBristol, param+" -bme700");
 	}
 
 	protected virtual void OnBsidPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -sid");
+		System.Diagnostics.Process.Start (startBristol, param+" -sid");
 	}
 
 	protected virtual void OnBmixerPressed (object sender, System.EventArgs e)
 	{
 		SetMode ();
-		System.Diagnostics.Process.Start ("startBristol "+param+" -mixer");
+		System.Diagnostics.Process.Start (startBristol, param+" -mixer");
 	}
 
 	//set default settings
@@ -1125,4 +1125,4 @@ protected virtual void OnChonnrpsizeToggled (object sender, System.EventArgs e)
 			}
 		}
 }
-}
\ No newline at end of file
+}
